==> joserfc-0.2.0.tar.gz: joserfc-0.2.0/src/joserfc/rfc7516/compact.py <==
import binascii
from .models import CompactEncryption, Recipient
from ..errors import (
    MissingAlgorithmError,
    MissingEncryptionError,
    DecodeError,
)
from ..util import (
    json_b64decode,
    urlsafe_b64encode,
    urlsafe_b64decode,
)


def represent_compact(obj: CompactEncryption) -> bytes:
    return b".".join([
        obj.base64_segments["aad"],
        urlsafe_b64encode(obj.recipient.encrypted_key),
        obj.base64_segments["iv"],
        obj.base64_segments["ciphertext"],
        obj.base64_segments["tag"],
    ])


def extract_compact(value: bytes) -> CompactEncryption:
    parts = value.split(b".")
    if len(parts) != 5:
        raise ValueError("Invalid JSON Web Encryption")

    header_segment, ek_segment, iv_segment, ciphertext_segment, tag_segment = parts
    try:
        protected = json_b64decode(header_segment)
        if "alg" not in protected:
            raise MissingAlgorithmError()
        if "enc" not in protected:
            raise MissingEncryptionError()
    except (TypeError, ValueError, binascii.Error):
        raise DecodeError("Invalid header")

    obj = CompactEncryption(protected)
    obj.base64_segments.update({
        "aad": header_segment,
        "iv": iv_segment,
        "ciphertext": ciphertext_segment,
        "tag": tag_segment,
    })
    obj.bytes_segments.update({
        "iv": urlsafe_b64decode(iv_segment),
        "ciphertext": urlsafe_b64decode(ciphertext_segment),
        "tag": urlsafe_b64decode(tag_segment),
    })
    recipient = Recipient(obj)
    recipient.encrypted_key = urlsafe_b64decode(ek_segment)
    obj.recipient = recipient
    return obj

==> joserfc-0.7.0.tar.gz: joserfc-0.7.0/src/joserfc/rfc7516/compact.py <==
from .models import CompactEncryption, Recipient
from ..rfc7517.models import BaseKey
from ..errors import (
    MissingAlgorithmError,
    MissingEncryptionError,
    DecodeError,
)
from ..util import (
    json_b64decode,
    urlsafe_b64encode,
    urlsafe_b64decode,
)


def represent_compact(obj: CompactEncryption) -> bytes:
    assert obj.recipient is not None
    encrypted_key = obj.recipient.encrypted_key
    assert encrypted_key is not None
    return b".".join([
        obj.base64_segments["aad"],
        urlsafe_b64encode(encrypted_key),
        obj.base64_segments["iv"],
        obj.base64_segments["ciphertext"],
        obj.base64_segments["tag"],
    ])


def extract_compact(value: bytes) -> CompactEncryption:
    parts = value.split(b".")
    if len(parts) != 5:
        raise ValueError("Invalid JSON Web Encryption")

    header_segment, ek_segment, iv_segment, ciphertext_segment, tag_segment = parts
    try:
        protected = json_b64decode(header_segment)
        if "alg" not in protected:
            raise MissingAlgorithmError()
        if "enc" not in protected:
            raise MissingEncryptionError()
    except (TypeError, ValueError):
        raise DecodeError("Invalid header")

    obj = CompactEncryption(protected)
    obj.base64_segments.update({
        "aad": header_segment,
        "iv": iv_segment,
        "ciphertext": ciphertext_segment,
        "tag": tag_segment,
    })
    obj.bytes_segments.update({
        "iv": urlsafe_b64decode(iv_segment),
        "ciphertext": urlsafe_b64decode(ciphertext_segment),
        "tag": urlsafe_b64decode(tag_segment),
    })
    recipient: Recipient[BaseKey] = Recipient(obj)
    recipient.encrypted_key = urlsafe_b64decode(ek_segment)
    obj.recipient = recipient
    return obj
